import numpy as np

def _get_window(window_size):
    return np.ones(int(window_size)) / float(window_size)
def _add_back_edges(x, x_smooth, edge_size):
    
    return np.hstack(
        [x[:edge_size], x_smooth[edge_size:-edge_size], x[-edge_size:]]
    )

def _smooth_1d_array(x, window_size, edge_size):
    
    """
    Calculate the moving average over a given window of an array.
    
    Parameters:
    -----------
    x
        1-d array
        type: numpy.ndarray
        
    window_size
        Number of items over which values should be smoothed.
        type: int
    
    edge_size
        type: int
        
    Returns:
    --------
    Array of a moving average of array values using the given window.
    """
    
    window = _get_window(window_size)
    x_smooth = np.convolve(x, window, "same")
    return _add_back_edges(x, x_smooth, edge_size)


import re
from ._flexible_multilevel_mkdir import _flexible_multilevel_mkdir

def _add_multithread_flag(command):
    return re.sub("gsutil", "gsutil -m", command)


def _mk_GCP_command(destination_path, bucket_path, command, multithreaded=True):

    """
    Create a gsutil cinnabd

    Parameters:
    -----------
    destination

    bucket_path

    Returns:
    --------
    gcp_command

    Notes:
    ------
    (1) It would be great to eventually replace this with a more streamlined API
        for performing gsutil-based commands from a python notebook interface.
    """

    _flexible_multilevel_mkdir(destination_path)
    gcp_command = "gsutil {} -r gs://{} {}".format(
        command, bucket_path, destination_path
    )
    if multithreaded:
        gcp_command = _add_multithread_flag(gcp_command)

    return gcp_command



# _create_empty_dict.py

__module_name__ = "_create_empty_dict.py"
__author__ = ", ".join(["Michael E. Vinyard"])
__email__ = ", ".join(["vinyard@g.harvard.edu",])


def _create_empty_dict(keys):

    """
    Create an empty python Dictionary given a set of keys.
    
    Parameters:
    -----------
    keys
    
    Returns:
    --------
    Dict
    """

    Dict = {}
    for key in keys:
        Dict[key] = {}

    return Dict


# __init__.py

from ._create_empty_dict import _create_empty_dict as create_empty_dict
from ._flexible_multilevel_mkdir import _flexible_multilevel_mkdir as mkdir_flex
from ._get_parent_directory import _get_parent_directory as parent_dir
from ._smooth_1d_array import _smooth_1d_array as smooth
from ._mk_GCP_command import _mk_GCP_command as gcp
from ._load_pickled import _load_pickled as load_pickled
from ._class_attributes import _class_attributes as class_attributes
from ._to_list import _to_list as to_list


from setuptools import setup
import re
import os
import sys


setup(
    name="pydk",
    version="0.0.4",
    python_requires=">3.7.0",
    author="Michael E. Vinyard - Harvard University - Massachussetts General Hospital - Broad Institute of MIT and Harvard",
    author_email="mvinyard@broadinstitute.org",
    url="",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    description="Python Developer Kit",
    packages=[
        "pydk",
    ],
    install_requires=[
        "licorice>=0.0.2",
    ],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python :: 3.7",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
    ],
    license="MIT",
)




import os

def _get_parent_directory(path, levels=1, verbose=False):
    
    """
    Parameters:
    -----------
    path
        input path
        type: str
    
    levels
        number of levels `os.path.dirname` should be called.
        type: int
        default: 1
    
    verbose
        if True, prints the resulting directory of each iteration.
        type: bool
        default: False
    
    Returns:
    --------
    path to parent directory
    """
    
    path_ = path
    for i in range(levels):
        path_ = os.path.dirname(path_)
        if verbose:
            print(i, path_)
            
    return path_
